﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Kinect;
using System.IO;

namespace ClothingSizeIdentificationUsingKinect
{
    class DepthData
    {
        #region Member Variables
        private const double MillimetrsPerCentimer = 0.1;
        private static readonly double HorizontalTanA = Math.Tan(57.5 / 2.0 * Math.PI / 180);
        private static readonly double VerticalTanA = Math.Abs(Math.Tan(43.5 / 2.0 * Math.PI / 180));

        private int _DepthSum;
        private int _DepthCount;
        private int _LoWidth;
        private int _HiWidth;
        private int _LoHeight;
        private int _HiHeight;
        #endregion Member Variables

        #region Constructor
        public DepthData(int userId, double frameWidth, double frameHeight)
        {
            this.UserId = userId;
            this.FrameWidth = frameWidth;
            this.FrameHeight = frameHeight;


            this._LoWidth = int.MaxValue;
            this._HiWidth = int.MinValue;

            this._LoHeight = int.MaxValue;
            this._HiHeight = int.MinValue;
        }
        #endregion Constructor

        #region Methods
        public void UpdateData(int x, int y, int depth)
        {
            this._DepthCount++;
            this._DepthSum += depth;
            this._LoWidth = Math.Min(this._LoWidth, x);
            this._HiWidth = Math.Max(this._HiWidth, x);
            this._LoHeight = Math.Min(this._LoHeight, y);
            this._HiHeight = Math.Max(this._HiHeight, y);
        }

        public bool DepthCheck()
        {
            if (Depth < 2700 && Depth < 2900)
            {
                return false;
            }
            else
            {
                return true;
            }

        }
        #endregion Methods

        #region Properties
        public int UserId { get; private set; }
        public double FrameWidth { get; private set; }
        public double FrameHeight { get; private set; }


        public double Depth
        {
            get { return this._DepthSum / (double)this._DepthCount; }
        }

        public int PixelWidth
        {
            get { return this._HiWidth - this._LoWidth; }
        }

        public int PixelHeight
        {
            get { return this._HiHeight - this._LoHeight; }
        }
                
        public double RealWidthMillimetrs
        {
            get
            {
                double b = this.Depth * HorizontalTanA;
                return this.PixelWidth * 2 * b / this.FrameWidth;
            }
        }

        public double RealHeightMillimetrs
        {
            get
            {
                double b = this.Depth * VerticalTanA;
                return this.PixelHeight * 2 * b / this.FrameHeight;
            }
        }
        #endregion Properties

        #region User measurement
        public double UserHeight()
        {
            return this.RealHeightMillimetrs * MillimetrsPerCentimer; 
        }

        public double UserWidth()
        {
            return this.RealWidthMillimetrs * MillimetrsPerCentimer; 
        }

        public double UserDepth()
        {
            return this.Depth * MillimetrsPerCentimer; 
        }
        #endregion User measurement
    }
}
