﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using Microsoft.Kinect;

namespace ClothingSizeIdentificationUsingKinect
{
    class KinectSensorItemCollection : ObservableCollection<KinectSensorItem>
    {
        private readonly Dictionary<KinectSensor, KinectSensorItem> sensorLookup = new Dictionary<KinectSensor, KinectSensorItem>();

        public Dictionary<KinectSensor, KinectSensorItem> SensorLookup
        {
            get
            {
                return this.sensorLookup;
            }
        }

        protected override void InsertItem(int index, KinectSensorItem item)
        {
            if (item == null)
            {
                throw new ArgumentException("Inserted item can't be null.", "item");
            }

            this.SensorLookup.Add(item.Sensor, item);
            base.InsertItem(index, item);
        }

        protected override void RemoveItem(int index)
        {
            this.SensorLookup.Remove(this[index].Sensor);
            base.RemoveItem(index);
        }

        protected override void ClearItems()
        {
            this.SensorLookup.Clear();
            base.ClearItems();
        }
    }
}
